nagios_host 'publications.ashp.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'ASHP',
		'address' => 'publications.ashp.org',
		'contact_groups' => 'cs_escalation,ashp',
		'notes' => 'ASHP Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/ASHP/pages/784499276/ASHP+-+Server+Setup'
end
nagios_host 'admin-publications.ashp.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'ASHP MGMT',
		'address' => 'admin-publications.ashp.org',
		'contact_groups' => 'cs_escalation,ashp',
		'notes' => 'ASHP Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/ASHP/pages/784499276/ASHP+-+Server+Setup'
end
nagios_host 'ams-publications.ashp.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'ASHP AMS',
		'address' => 'ams-publications.ashp.org',
		'contact_groups' => 'cs_escalation,ashp',
		'notes' => 'ASHP Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/ASHP/pages/784499276/ASHP+-+Server+Setup'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live ASHP site and checks for the string 'ASHP'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'publications.ashp.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'publications.ashp.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!ashp:ashp2019!/!"ASHP"!10!20!',
		'contact_groups' => 'cs_escalation,ashp',
		'notes' => 'ASHP Live Site',
		'notes_url' => 'https://publications.ashp.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live ASHP site and checks for the string ''.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'publications.ashp.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'publications.ashp.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!ashp:ashp2019!/search!Browse!10!20!',
		'contact_groups' => 'cs_escalation,ashp',
		'notes' => 'ASHP Live Site',
		'notes_url' => 'https://publications.ashp.org/browse'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live ASHP site and checks for the string 'ASHP'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'publications.ashp.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'publications.ashp.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!ashp:ashp2019!/view/book/9781585286133/ch005.xml!ASHP!10!20!',
		'contact_groups' => 'cs_escalation,ashp',
		'notes' => 'ASHP Live Site',
		'notes_url' => 'https://publications.ashp.org/view/book/9781585286133/ch005.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'ASHP PROD' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'publications.ashp.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin-publications.ashp.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin-publications.ashp.org!/login!ashp:ashp2019!"ASHP Production"!20!10',
		'contact_groups' => 'admins_email_only,ashp',
		'notes' => 'ASHP Live Loader',
		'notes_url' => 'https://admin-publications.ashp.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'ASHP' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'publications.ashp.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'publications.ashp.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging-publications.ashp.org!ashp:ashp2019!"ASHP"!20!10',
		'contact_groups' => 'admins_email_only,ashp',
		'notes' => 'ASHP Staging Site',
		'notes_url' => 'staging-publications.ashp.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'publications.ashp.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams-publications.ashp.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams-publications.ashp.org!/login!ashp:ashp2019!AMS!20!10',
		'contact_groups' => 'admins_email_only,ashp',
		'notes' => 'ASHP AMX',
		'notes_url' => 'https://ams-publications.ashp.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'publications.ashp.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'publications.ashp.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!publications.ashp.org!ashp:ashp2019!"provisional account"',
		'contact_groups' => 'admins_email_only,ashp',
		'notes' => 'ASHP Live Site Failopen',
		'notes_url' => 'https://publications.ashp.org/'
end
